These are internal functions of package quantregGrowth and should be not
called by the user.
ncross.rq.fitXB(y, x, B=NULL, X=NULL, taus, monotone=FALSE, concave=FALSE,
nomiBy=NULL, byVariabili=NULL, ndx=10, deg=3, dif=3, lambda=0, eps=.0001,
var.pen=NULL, penMatrix=NULL, lambda.ridge=0, dropcList=FALSE,
decomList=FALSE, vcList=FALSE, dropvcList=FALSE, centerList=FALSE,
ridgeList=FALSE, ps.matrix.list=FALSE, colmeansB=NULL, Bconstr=NULL,
adjX.constr=TRUE, adList=FALSE, it.j=10, myeps=NULL, nc=TRUE, lassoList=FALSE, ...)ncross.rq.fitXBsparse(y, x, B=NULL, X=NULL, taus, monotone=FALSE, concave=FALSE,
nomiBy=NULL, byVariabili=NULL, ndx=10, deg=3, dif=3, lambda=0, eps=.0001,
var.pen=NULL, penMatrix=NULL, lambda.ridge=0, dropcList=FALSE, decomList=FALSE,
vcList=FALSE, dropvcList=FALSE, centerList=FALSE, ridgeList=FALSE,
ps.matrix.list=FALSE, colmeansB=NULL, Bconstr=NULL, adjX.constr=TRUE,
adList=FALSE, it.j=10, myeps=NULL, nc=TRUE, ...)
ncross.rq.fitX(y, X = NULL, taus, adjX.constr=TRUE, lambda.ridge = 0,
eps = 1e-04, sparse=FALSE, nc.fit=FALSE, ...)
gcrq.rq.cv(y, B, X, taus, monotone, concave, ndx, lambda, deg, dif, var.pen=NULL,
penMatrix=NULL, lambda.ridge=0, dropcList=FALSE, decomList=FALSE,
vcList=vcList, dropvcList=FALSE, nfolds=10, foldid=NULL, eps=.0001,
sparse=FALSE, ...)
A list of fit information.
the responses vector. see gcrq
the covariate supposed to have a nonlinear relationship.
the B-spline basis.
the design matrix for the linear parameters.
the percentiles of interest.
numerical value (-1/0/+1) to define a non-increasing, unconstrained, and non-decreasing flexible fit, respectively.
numerical value (-1/0/+1) to possibly define concave or convex fits.
useful for VC models (when B is not provided).
useful for VC models (when B is not provided).
number of internal intervals within the covariate range, see ndx in ps.
spline degree, see ps.
difference order of the spline coefficients in the penalty term.
smoothing parameter value(s), see lambda in ps.
tolerance value.
Varying penalty, see ps.
Specified penalty matrix, see pen.matrix in ps.
a (typically very small) value, see lambda.ridge gcrq.
see dropc in ps.
see decompose in ps.
to indicate if the smooth is VC or not, see by in ps.
see ps.
see center in ps.
see ridge in ps.
nothing relevant for the user.
see center in ps.
see constr.fit in ps.
vector (optional) to perform cross validation, see the same arguments in gcrq.
number of folds for crossvalidation, see the same arguments in gcrq.
returning cv scores; see the same arguments in gcrq.
logical to shift the linear covariates. Appropriate only with linear terms.
see ad in ps.
Ignore.
Ignore.
logical, meaning if sparse computations have to be used.
nothing relevant for the user.
logical, nothing relevant for the user.
logical, nothing relevant for the user.
optional.
Vito M. R. Muggeo
These functions are called by gcrq to fit growth charts based on regression
quantiles with non-crossing and monotonicity restrictions. The computational methods are based on the package
quantreg by R. Koenker and details are described in the reference paper.
gcrq